local SteadyClaw_NextSpamable = 0
local SteadyClaw_ABILMAP = {
    ["Cat"] = { primary = "Bite", primaryFocus = 35, spamable = "Claw", spamableFocus = 25 },
    ["Ravager"] = { primary = "Bite", primaryFocus = 35, spamable = "Gore", spamableFocus = 25 },
    ["Scorpid"] = { primary = "Scorpid Poison", primaryFocus = 30, spamable = "Claw", spamableFocus = 25 },
}

function SteadyClaw(debug)
    local abilMap = SteadyClaw_ABILMAP[UnitCreatureFamily("pet")]
    
    if not abilMap then
        if debug then Print("Improper pet family") end
        return
    end
    
    local actionIndex, actionName, primaryIndex, spamableIndex
    for actionIndex = 1, NUM_PET_ACTION_SLOTS do
        actionName = GetPetActionInfo(actionIndex)
        if actionName == abilMap.primary then
            primaryIndex = actionIndex
        elseif actionName == abilMap.spamable then
            spamableIndex = actionIndex
        end
    end -- for index
    
    -- can't find our two things
    if not (primaryIndex and spamableIndex) then
        if debug then Print("Can't find indexes") end
        return 
    end
    
    -- First check to see if the primary action has less than global cooldown left
    local startTime, duration, enbl = GetPetActionCooldown(primaryIndex)
    if startTime == 0 or duration == 0 then 
        if debug then Print("Primary action ready!") end
        return
    end
    local durationRemaining = (startTime + duration) - GetTime()
    if durationRemaining <= 1.0 then 
        if debug then Print("Primary action almost ready") end
        return 
    end
        
    -- Next check to see if spammable action is up
    startTime, duration, enbl = GetPetActionCooldown(spamableIndex)
    if startTime ~= 0 or duration ~= 0 or SteadyClaw_NextSpamable > GetTime() then 
        if debug then Print("Spammable on cooldown") end
        return 
    end
    
    -- Finally check that we have enough focus
    if UnitMana("pet") >= (abilMap.primaryFocus + abilMap.spamableFocus) then
        if debug then Print("Casting spamable "..startTime.." "..duration.." "..enbl) end
        SteadyClaw_NextSpamable = GetTime() + 1.5
        return SteadyClawSecureButton:Click()
        -- UIErrorsFrame:UnregisterEvent("UI_ERROR_MESSAGE")
        -- UIErrorsFrame:RegisterEvent("UI_ERROR_MESSAGE")
        -- CastSpellByName(abilMap.spamable)
        -- CastPetAction(spamableIndex)
    end
end

function SteadyClaw_OnLoad()
    SteadyClawSecureButton:RegisterEvent("UNIT_PET")
    SteadyClawSecureButton:RegisterEvent("PLAYER_REGEN_ENABLED")
end

function SteadyClaw_OnEvent(event, arg1)
    -- "PET_BAR_UPDATE" too?
    if (event == "PLAYER_REGEN_ENABLED") or
        (event == "UNIT_PET" and arg1 == "player") then
        local abilMap = UnitCreatureFamily("pet") and SteadyClaw_ABILMAP[UnitCreatureFamily("pet")]
        if not abilMap then return end
        -- Print("Setting ability to "..abilMap.spamable) 
        return SteadyClawSecureButton:SetAttribute("spell", abilMap.spamable)
    end
end
